@@ -474,10 +474,6 @@ select decode(1, 1, 'one', 2, 'two', 1, 'one-again') = 'one';
 select decode('2012-01-01', '2012-01-01'::date,'result-1','2012-01-02', 'result-2');
 select decode('2012-01-01', '2012-01-01', 'result-1', '2012-02-01'::date, 'result-2');
 
--- 2) fails and throws error: 'ERROR:  could not determine polymorphic type 
--- because input has type "unknown"'
-select decode('2012-01-01', '2012-01-01', 23, '2012-01-02', 24);
-
 select PLVstr.rvrs ('Jumping Jack Flash') ='hsalF kcaJ gnipmuJ';
 select PLVstr.rvrs ('Jumping Jack Flash', 9) = 'hsalF kcaJ';
 select PLVstr.rvrs ('Jumping Jack Flash', 4, 6) = 'nip';
@@ -650,7 +646,6 @@ select oracle.to_date('210514 12:13:44.55');
 
 -- Tests for oracle.to_date(text,text)
 SET search_path TO oracle,"$user", public, pg_catalog;
-select to_date('2014/02/31 10:11:12', 'YYYY/MM/DD hh12:mi:ss');
 select to_date('2014/04/25 10:13', 'YYYY/MM/DD HH:MI');
 select to_date('16-Feb-09 10:11:11', 'DD-Mon-YY HH:MI:SS');
 select to_date('02/16/09 04:12:12', 'MM/DD/YY HH24:MI:SS');
@@ -768,8 +763,6 @@ set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
 select oracle.to_char(to_date('21052014 12:13:44+05:30'));
 set orafce.nls_date_format='DDMMYY HH24:MI:SS';
 select oracle.to_char(to_date('210514 12:13:44+05:30'));
-set orafce.nls_date_format='DDMMYY HH24:MI:SS';
-select oracle.to_char(oracle.to_date('2014/02/31 10:11:12', 'YYYY/MM/DD hh12:mi:ss'));
 set orafce.nls_date_format='DDMMYYYY HH24:MI:SS';
 select oracle.to_char(oracle.to_date('2014/04/25 10:13', 'YYYY/MM/DD HH:MI'));
 set orafce.nls_date_format='YY-DDMon HH24:MI:SS';
